import java.io.*;
import java.util.*;

/** A class to define keys on a keyboard.
*
* Each key is defined by four arguments: a String representing the
* character on the key, the key's <i>x</i> coordinate,
* the key's <i>y</i> coordinate, and the width of the key.<p>
*
* For example, the
* file <code>CHIKeys.txt</code> represents the keypad on a Nokia 5110 mobile
* phone, as per Silfverberg et al. (2000).  Here are
* the contents:<p>
*
* <pre>
*     #  26.5  27 5
*     *  0     27 5
*     S  13.25 27 6
*     1  0     0  6
*     2  13.25 0  6
*     3  26.5  0  6
*     4  0     9  6
*     5  13.25 9  6
*     6  26.5  9  6
*     7  0     18 6
*     8  13.25 18 6
*     9  26.5  18 6
*     N  25.5  -9 6
* </pre>
*
* @author Scott MacKenzie, 2001                             
*/
public class Key
{
   private String key;
   private double x;
   private double y;
   private double w;

   public Key(String s, double d1, double d2, double d3)
   {
      key = s;
      x = d1;
      y = d2;
      w = d3;
   }

   public double getX() { return x; }
   public double getY() { return y; }
   public double getW() { return w; }
   public String getKey() { return key; }

   /** Return the pythagorean distance from <code>this</code> key to
   * the specified key.
   *
   * @param k the specified <code>Key</code> object to compute the distance to.
   * @return a double representing the distance between the two keys.
   */
   public double distanceTo(Key k)
   {
      double xx = Math.abs(x - k.getX());
      double yy = Math.abs(y - k.getY());
      return Math.sqrt(xx * xx + yy * yy);
   }

   @Override
public String toString()
   {
      return "Key: " + key + " (x=" + x + ",y=" + y + ",w=" + w +")";
   }

   /** Test the <code>Key</code> class.<p>
   *
   * Invocation:<p>
   *
   * <pre>
   *     PROMPT>java Key < keys.txt
   * </pre>
   *
   * where <code>keys.txt</code> is a text file containing the
   * representation of a keyboard.
   */
   public static void main(String[] args) throws IOException
   {
      BufferedReader stdin =
         new BufferedReader(new InputStreamReader(System.in), 1);
      
      String line;
      StringTokenizer st;
      Key[] k = new Key[100];
      int kCount = 0;
      while ((line = stdin.readLine()) != null)
      {
         st = new StringTokenizer(line);
         if (st.countTokens() != 4)
         {
            System.out.println("data format error!");
            System.exit(1);
         }
         String s;
         double d1, d2, d3;
         s = st.nextToken();
         d1 = Double.parseDouble(st.nextToken());
         d2 = Double.parseDouble(st.nextToken());
         d3 = Double.parseDouble(st.nextToken());
         k[kCount] = new Key(s, d1, d2, d3);
         ++kCount;
      }
      for (int i = 0; i < kCount; ++i)
      {
         System.out.println(k[i]);
         System.out.println("   Distance to...");
         for (int j = 0; j < kCount; ++j)
         {
            System.out.println("   " + k[j] + ": " + k[i].distanceTo(k[j]));
         }
      }
   }
}
